@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec;
 
-our $DATE = '2017-07-07'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2018-09-22'; # DATE
+our $VERSION = '0.060'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,6 +42,15 @@ sub _prereq_only_in {
     $num_wanted == 1 && $num_any == 1;
 }
 
+sub _has_prereq {
+    my ($self, $prereqs_hash, $mod, $wanted_phase, $wanted_rel) = @_;
+
+    my ($num_any, $num_wanted) = $self->_prereq_check(
+        $prereqs_hash, $mod, $wanted_phase, $wanted_rel,
+    );
+    $num_wanted == 1;
+}
+
 sub _prereq_none {
     my ($self, $prereqs_hash, $mod) = @_;
 
@@ -61,8 +70,8 @@ sub after_build {
         $self->log_fatal(["Dist defines Rinci metadata or implements Rinci, but there is no prereq phase=develop rel=x_spec to Rinci"])
             unless $self->_prereq_only_in($prereqs_hash, "Rinci", "develop", "x_spec");
     } else {
-        $self->log_fatal(["Dist does not define Rinci metadata, but there is a prereq to Rinci"])
-            unless $self->_prereq_none($prereqs_hash, "Rinci");
+        $self->log_fatal(["Dist does not define Rinci metadata, but there is a phase=develop rel=xpec prereq to Rinci"])
+            if $self->_has_prereq($prereqs_hash, "Rinci", "develop", "x_spec");
     }
 }
 
@@ -82,7 +91,7 @@ Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec - Ensure prereq to spec modul
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2017-07-07.
+This document describes version 0.060 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2018-09-22.
 
 =head1 SYNOPSIS
 
@@ -122,7 +131,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
